#ifdef SVR4
pid_t	lookup_proc(char *);
#else
int	lookup_proc();
#endif
